# 🎁 Release notes ({{ version }})

## Changes
```
{% for change in changes %}
{{ change }}
{% endfor %}
```

## Metadata
```
This version -------- {{ version }}
Previous version ---- {{ prev_version }}
Total commits ------- {{ commits }}
```
